<?php
/** 
 * @package   	VikWP - Libraries
 * @subpackage 	adapter.event
 * @author    	E4J s.r.l.
 * @copyright 	Copyright (C) 2019 E4J s.r.l. All Rights Reserved.
 * @license  	http://www.gnu.org/licenses/gpl-2.0.html GNU/GPL
 * @link 		https://vikwp.com
 */

// No direct access
defined('ABSPATH') or die('No script kiddies please!');

/**
 * Class to handle dispatching of events.
 *
 * @since 10.1.11
 */
class JEventDispatcher
{
	/**
	 * Stores the singleton instance of the dispatcher.
	 *
	 * @var JEventDispatcher
	 */
	protected static $instance = null;

	/**
	 * Returns the global Event Dispatcher object, only creating it
	 * if it doesn't already exist.
	 *
	 * @return  JEventDispatcher  The EventDispatcher object.
	 */
	public static function getInstance()
	{
		if (self::$instance === null)
		{
			self::$instance = new static();
		}

		return self::$instance;
	}

	/**
	 * Triggers an event by dispatching arguments to all observers that handle
	 * the event and returning their return values.
	 *
	 * @param   string  $event  The event to trigger.
	 * @param   array   $args   An array of arguments.
	 *
	 * @return  array  An array of results from each called function.
	 */
	public function trigger($event, $args = array())
	{
		// make sure we are passing an array of arguments
		$args = (array) $args;

		// Push an empty value at the beginning of the list for being 
		// manipulated at every execution of the filter.
		array_unshift($args, null);

		/**
		 * Trigger the event.
		 * Use `apply_filters_ref_array` instead of `do_action_ref_array`
		 * to start supporting return values.
		 *
		 * @since 10.1.23
		 */
		$return = apply_filters_ref_array($event, $args);

		if (is_null($return))
		{
			// return an empty list as none manipulated the return value
			return array();
		}

		// push the returned value within a list for Joomla standards
		return array($return);
	}
}
