<?php
/** 
 * @package   	VikWP - Libraries
 * @subpackage 	adapter.html
 * @author    	E4J s.r.l.
 * @copyright 	Copyright (C) 2019 E4J s.r.l. All Rights Reserved.
 * @license  	http://www.gnu.org/licenses/gpl-2.0.html GNU/GPL
 * @link 		https://vikwp.com
 */

// No direct access
defined('ABSPATH') or die('No script kiddies please!');

/**
 * Utility class for form related behaviors.
 *
 * @since 10.1.16
 */
abstract class JHtmlFormbehavior
{
	/**
	 * Method to load the Chosen JavaScript framework and supporting CSS into the document head.
	 *
	 * @param   string  $selector  Class for Chosen elements.
	 * @param   mixed   $debug     Is debugging mode on? [optional].
	 * @param   array   $options   The possible Chosen options as name => value [optional].
	 *
	 * @return  void
	 */
	public static function chosen($selector = '.btn-toolbar', $debug = null, $options = array())
	{
		static $loaded = 0;

		// register only once
		if ($loaded)
		{
			return;
		}

		$loaded = 1;

		// load always select2 plugin
		JHtml::_('select2');
		JText::script('JGLOBAL_SELECT_AN_OPTION');

		// add support for chosen plugin
		JFactory::getDocument()->addScriptDeclaration(
<<<JS
if (jQuery.fn.chosen === undefined) {
	jQuery.fn.chosen = function(data) {
		if (data !== undefined) {
			// invoke requested method (e.g. destroy)
			jQuery(this).select2(data);
		} else {
			// iterate all selected elements
			jQuery(this).each(function() {
				data = {};
				data.width       = 250;
				data.allowClear  = jQuery(this).hasClass('required') ? false : true;
				data.placeholder = Joomla.JText._('JGLOBAL_SELECT_AN_OPTION');

				// in case we don't have an empty option, unset placeholder
				if (jQuery(this).find('option').first().val().length > 0) {
					data.allowClear  = false;
					data.placeholder = null;
				}

				// turn off search when there are 5 options or less
				if (jQuery(this).find('option').length <= 5) {
					data.minimumResultsForSearch = -1;
				}

				// init select2 plugin
				jQuery(this).select2(data);
			});
		}

		return this;
	}
}

jQuery(document).ready(function() {
	jQuery('{$selector}')
		.find('select')
			.chosen()
				.on('chosen:updated', function() {
					// refresh select2 value when triggered
					jQuery(this).select2('val', jQuery(this).val());
				});
});
JS
		);
	}
}
