<?php
/** 
 * @package   	VikWP - Libraries
 * @subpackage 	adapter.module
 * @author    	E4J s.r.l.
 * @copyright 	Copyright (C) 2019 E4J s.r.l. All Rights Reserved.
 * @license  	http://www.gnu.org/licenses/gpl-2.0.html GNU/GPL
 * @link 		https://vikwp.com
 */

// No direct access
defined('ABSPATH') or die('No script kiddies please!');

/**
 * Helper class for WP widgets.
 *
 * @since 10.0
 */
class JModuleHelper
{
	/**
	 * Absolute path of the module.
	 * Since this class is located in the adapter package, it doesn't
	 * know the base path in which all the modules are located.
	 * This means that the path should be changed every time a module 
	 * is going to be rendered.
	 *
	 * @var string
	 */
	protected static $path = null;

	/**
	 * Sets the base path in which the module is contained.
	 * The path should include also the module name.
	 *
	 * @param 	string 	$path 	The module path.
	 *
	 * @return 	void
	 */
	public static function setPath($path)
	{
		static::$path = rtrim($path, DIRECTORY_SEPARATOR);
	}

	/**
	 * Gets the current base path.
	 *
	 * @param 	string 	$name 	The module name (optional). 
	 *
	 * @return 	string 	The module path
	 */
	public static function getPath($name = null)
	{
		// return null if no path
		if (!static::$path)
		{
			return null;
		}

		// if the name is provided, make sure the path already contains it
		if ($name)
		{
			// get the path chunks
			$parts = explode(DIRECTORY_SEPARATOR, static::$path);

			// if the last chunk doesn't match the module name, append it
			if (end($parts) != $name)
			{
				$parts[] = $name;
			}

			// implode the chunks with the DS
			return implode(DIRECTORY_SEPARATOR, $parts);
		}

		return static::$path;
	}

	/**
	 * Returns the layout path of the module.
	 *
	 * @param 	string 	$module 	The module name.
	 * @param 	string 	$layout 	The module layout name.
	 *
	 * @return 	string 	The module layout path (relative).
	 */
	public static function getLayoutPath($module, $layout = null)
	{
		if (!$layout)
		{
			$layout = 'default';
		}
		else if (strpos($layout, DIRECTORY_SEPARATOR) !== false && is_file($layout))
		{
			/**
			 * The layout is an absolute path that points to an existing
			 * override file. Use it instead of the default one.
			 *
			 * @since 10.1.2
			 */
			return $layout;
		}

		// construct the layout path of the default module
		$parts = array();
		$parts[] = static::getPath($module);
		$parts[] = 'tmpl';
		$parts[] = $layout . '.php';

		return implode(DIRECTORY_SEPARATOR, array_filter($parts));
	}
}
